# group-array [![NPM version](https://badge.fury.io/js/group-array.svg)](http://badge.fury.io/js/group-array)  [![Build Status](https://travis-ci.org/doowb/group-array.svg)](https://travis-ci.org/doowb/group-array)

> Group array of objects into lists.

Install with [npm](https://www.npmjs.com/)

```sh
$ npm i group-array --save
```

## Usage

```js
var groupArray = require('group-array');
```

## API

### [groupBy](index.js#L63)

Create groupings from array's values.

**Params**

* `arr` **{Array}**: Array to group.
* `grouper` **{Function}**: Optional grouping function that takes `acc, value, i, arr, setter`
* `setter` **{Function}**: Optional setter function that takes `acc, group, value, i, arr`
* `acc` **{Object|Array}**: Optional accumulator object or array passed to the setter function.
* `returns` **{Object|Array}**: Object or array containing groups as keys and list of objects as values in the group.

**Example**

```js
function grouper (acc, value, i, arr, setter) {
  return value.group;
}

function setter (acc, group, value, i, arr) {
  acc[group] = acc[group] || [];
  acc[group].push(value);
}

var arr = [
  { group: 'one', content: 'A'},
  { group: 'one', content: 'B'},
  { group: 'two', content: 'C'},
  { group: 'two', content: 'D'},
  { group: 'three', content: 'E'},
  { group: 'three', content: 'F'}
];

var groups = groupBy(arr, grouper, setter);
//=> {
//=>   one: [
//=>     { group: 'one', content: 'A'},
//=>     { group: 'one', content: 'B'}
//=>   ],
//=>   two: [
//=>     { group: 'two', content: 'C'},
//=>     { group: 'two', content: 'D'}
//=>   ],
//=>   three: [
//=>     { group: 'three', content: 'E'},
//=>     { group: 'three', content: 'F'}
//=>   ]
//=> }
```

## Related projects

* [arr-reduce](https://github.com/jonschlinkert/arr-reduce): Fast array reduce that also loops over sparse elements.
* [group-object](https://github.com/doowb/group-object): Group object keys and values into lists.
* [get-value](https://github.com/jonschlinkert/get-value): Use property paths (`  a.b.c`) to get a nested value from an object.
* [union-value](https://github.com/jonschlinkert/union-value): Set an array of unique values as the property of an object. Supports setting deeply… [more](https://github.com/jonschlinkert/union-value)

## Running tests

Install dev dependencies:

```sh
$ npm i -d && npm test
```

## Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](https://github.com/doowb/group-array/issues/new)

## Author

**Brian Woodward**

+ [github/doowb](https://github.com/doowb)
+ [twitter/doowb](http://twitter.com/doowb)

## License

Copyright © 2015 Brian Woodward
Released under the MIT license.

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on July 19, 2015._